@@ -3,10 +3,11 @@
 ;;; Code:
 
 (custom-add-loads 'gnus-start '("gnus-group" "gnus-int" "gnus-start" "gnus-util" "gnus"))
+(custom-add-loads 'gnus-exit '("gnus-group" "gnus"))
 (custom-add-loads 'message '("message"))
 (custom-add-loads 'gnus-score-expire '("gnus-kill" "gnus-score"))
-(custom-add-loads 'gnus-score-kill '("gnus-kill"))
-(custom-add-loads 'gnus-message '("message"))
+(custom-add-loads 'gnus-score-kill '("gnus-kill" "gnus"))
+(custom-add-loads 'gnus-message '("message" "gnus"))
 (custom-add-loads 'gnus-summary-sort '("gnus-sum"))
 (custom-add-loads 'nnmail-procmail '("nnmail"))
 (custom-add-loads 'gnus-article-buttons '("gnus-art"))
@@ -18,18 +19,22 @@
 (custom-add-loads 'gnus-article-emphasis '("gnus-art"))
 (custom-add-loads 'earcon '("earcon"))
 (custom-add-loads 'gnus-group-foreign '("gnus-group"))
+(custom-add-loads 'gnus-undo '("gnus-undo"))
 (custom-add-loads 'gnus-article-washing '("gnus-xmas" "gnus-art"))
 (custom-add-loads 'mail '("gnus" "message"))
-(custom-add-loads 'gnus-summary-exit '("gnus-sum"))
-(custom-add-loads 'gnus-article-saving '("gnus-art"))
+(custom-add-loads 'gnus-summary-exit '("gnus-sum" "gnus"))
+(custom-add-loads 'gnus-article-saving '("gnus-art" "gnus"))
 (custom-add-loads 'gnus-extract-view '("gnus-sum" "gnus-uu"))
 (custom-add-loads 'gnus-group-listing '("gnus-group"))
 (custom-add-loads 'gnus-summary '("gnus-sum" "gnus"))
 (custom-add-loads 'message-headers '("message"))
-(custom-add-loads 'gnus-group-select '("gnus-sum"))
+(custom-add-loads 'gnus-group-select '("gnus-sum" "gnus"))
+(custom-add-loads 'gnus-score-various '("gnus-score" "gnus"))
+(custom-add-loads 'gnus-server '("gnus"))
+(custom-add-loads 'gnus-meta '("gnus"))
 (custom-add-loads 'gnus-summary-mail '("gnus-sum"))
 (custom-add-loads 'gnus-score-default '("gnus-score" "gnus-sum"))
-(custom-add-loads 'nnmail-expire '("nnmail"))
+(custom-add-loads 'nnmail-expire '("gnus" "nnmail"))
 (custom-add-loads 'gnus-thread '("gnus-sum"))
 (custom-add-loads 'gnus-nocem '("gnus-nocem"))
 (custom-add-loads 'gnus-threading '("gnus-sum"))
@@ -37,27 +42,33 @@
 (custom-add-loads 'gnus-extract '("gnus" "gnus-uu"))
 (custom-add-loads 'gnus-summary-tree '("gnus-salt"))
 (custom-add-loads 'nnmail-split '("nnmail"))
+(custom-add-loads 'gnus-dribble-file '("gnus-start"))
 (custom-add-loads 'gnus-article-various '("gnus-art" "gnus-sum"))
-(custom-add-loads 'message-sending '("auto-autoloads" "message"))
+(custom-add-loads 'gnus-group-new '("gnus-start"))
+(custom-add-loads 'message-sending '("message"))
 (custom-add-loads 'gnus-article '("gnus-art" "gnus-cite"))
-(custom-add-loads 'gnus '("gnus-art" "gnus-async" "gnus-cache" "gnus-demon" "gnus-dup" "gnus-eform" "gnus-uu" "gnus-win" "gnus-xmas" "gnus" "nnmail"))
+(custom-add-loads 'gnus-agent '("gnus-agent"))
+(custom-add-loads 'gnus '("gnus-art" "gnus" "gnus-demon" "gnus-dup" "gnus-eform" "gnus-undo" "gnus-uu" "gnus-win" "gnus-xmas" "nnmail"))
 (custom-add-loads 'gnus-xmas '("gnus-xmas"))
 (custom-add-loads 'gnus-treading '("gnus-sum"))
 (custom-add-loads 'nnmail '("nnmail"))
 (custom-add-loads 'gnus-article-hiding '("gnus-art" "gnus-sum"))
 (custom-add-loads 'nnmail-duplicate '("nnmail"))
 (custom-add-loads 'gnus-summary-visual '("gnus-sum" "gnus"))
-(custom-add-loads 'gnus-group-various '("gnus-group"))
+(custom-add-loads 'gnus-group-various '("gnus-group" "gnus"))
 (custom-add-loads 'nnmail-retrieve '("nnmail"))
 (custom-add-loads 'message-interface '("message"))
 (custom-add-loads 'gnus-group '("gnus-topic" "gnus"))
 (custom-add-loads 'gnus-article-signature '("gnus-art"))
 (custom-add-loads 'gnus-duplicate '("gnus-dup"))
-(custom-add-loads 'gnus-score-adapt '("gnus-score"))
+(custom-add-loads 'gnus-score-adapt '("gnus-score" "gnus"))
 (custom-add-loads 'nnmail-various '("nnmail"))
+(custom-add-loads 'gnus-group-level '("gnus"))
 (custom-add-loads 'nnmail-files '("nnmail"))
-(custom-add-loads 'gnus-asynchronous '("gnus-async"))
+(custom-add-loads 'gnus-asynchronous '("gnus" "gnus-async"))
+(custom-add-loads 'gnus-group-visual '("gnus-group" "gnus"))
 (custom-add-loads 'gnus-visual '("earcon" "gnus-art" "gnus-picon" "gnus" "smiley"))
+(custom-add-loads 'message-forwarding '("message"))
 (custom-add-loads 'message-news '("message"))
 (custom-add-loads 'gnus-edit-form '("gnus-eform"))
 (custom-add-loads 'gnus-files '("gnus" "nnmail"))
@@ -66,19 +77,24 @@
 (custom-add-loads 'gnus-demon '("gnus-demon"))
 (custom-add-loads 'gnus-summary-choose '("gnus-sum"))
 (custom-add-loads 'gnus-windows '("gnus-win"))
-(custom-add-loads 'message-mail '("auto-autoloads" "message"))
+(custom-add-loads 'message-mail '("message"))
+(custom-add-loads 'gnus-newsrc '("gnus-start"))
 (custom-add-loads 'message-various '("message"))
-(custom-add-loads 'gnus-group-levels '("gnus-group"))
-(custom-add-loads 'gnus-summary-format '("gnus-sum"))
+(custom-add-loads 'gnus-group-levels '("gnus-group" "gnus-start" "gnus"))
+(custom-add-loads 'gnus-summary-format '("gnus-sum" "gnus"))
 (custom-add-loads 'gnus-score-decay '("gnus-score"))
 (custom-add-loads 'gnus-extract-post '("gnus-uu"))
 (custom-add-loads 'faces '("gnus" "message"))
-(custom-add-loads 'gnus-various '("gnus-sum"))
-(custom-add-loads 'gnus-article-highlight '("gnus-art"))
+(custom-add-loads 'gnus-various '("gnus-sum" "gnus"))
+(custom-add-loads 'smiley '("smiley"))
+(custom-add-loads 'gnus-start-server '("gnus-start"))
+(custom-add-loads 'gnus-article-highlight '("gnus-art" "gnus"))
 (custom-add-loads 'news '("gnus" "message"))
-(custom-add-loads 'message-insertion '("auto-autoloads"))
-(custom-add-loads 'gnus-score-files '("gnus-score"))
-(custom-add-loads 'gnus-summary-marks '("gnus-sum"))
+(custom-add-loads 'gnus-cache '("gnus-cache" "gnus"))
+(custom-add-loads 'message-insertion '("message"))
+(custom-add-loads 'message-faces '("message"))
+(custom-add-loads 'gnus-score-files '("gnus-score" "gnus"))
+(custom-add-loads 'gnus-summary-marks '("gnus-sum" "gnus"))
 (custom-add-loads 'picons '("gnus-picon"))
 (custom-add-loads 'nnmail-prepare '("nnmail"))
 (custom-add-loads 'message-buffers '("message"))
